intelmq.bots.collectors.stomp package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.stomp package

## Submodules

## intelmq.bots.collectors.stomp.collector module

intelmq.bots.collectors.stomp.collector.BOT

  alias of `intelmq.bots.collectors.stomp.collector.StompCollectorBot`

class intelmq.bots.collectors.stomp.collector.StompCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect data from a STOMP Interface

  exchange: str = ''
  heartbeat: int = 6000
  init()
  port: int = 61614
  process()
  server: str = 'n6stream.cert.pl'
  shutdown()
  ssl_ca_certificate: str = 'ca.pem'
  ssl_client_certificate: str = 'client.pem'
  ssl_client_certificate_key: str = 'client.key'

class intelmq.bots.collectors.stomp.collector.StompListener(n6stompcollector, conn, destination)

  Bases: `stomp.listener.PrintingListener`

  the stomp listener gets called asynchronously for every STOMP message

  on_disconnected()

    Called by the STOMP connection when a TCP/IP connection to the STOMP server has been lost. No messages should be sent via the connection until it has been reestablished.

  on_error(headers, message)
    Parameters

      frame (Frame) – the stomp frame

  on_heartbeat_timeout()

    Called by the STOMP connection when a heartbeat message has not been received beyond the specified period.

  on_message(headers, message)
    Parameters

      frame (Frame) – the stomp frame

intelmq.bots.collectors.stomp.collector.connect_and_subscribe(conn, logger, destination, start=False)

## Module contents